@@ -21,117 +21,12 @@ class specTrails(object):
     """
 
 
-    def __init__(self, temperature, density):
-        self.Temperature = temperature
-        self.EDensity = density
-        self.AbundanceName = chdata.Defaults['abundfile']
-        self.AbundAll = chdata.Abundance[self.AbundanceName]['abundance']
-        #
-        # ---------------------------------------------------------------------------
-        #
-    def convolve(self, wavelength=0, filter=(chfilters.gaussianR, 1000.), label=0, verbose=False):
-        '''
-        the first application of spectrum calculates the line intensities within the specified wavelength range and for set of ions specified
-
-        wavelength will not be used if applied to 'spectrum' objects
-
-        wavelength IS need for 'bunch' objects - in this case, the wavelength should not extend beyond the limits of the
-        wvlRange used for the 'bunch' calculation
-
-        Keyword Arguments
-        -----------------
-
-        wavelength:  'int', `list`
-            if an `int`, the attribute 'Wavelength' is looked for
-            otherwise, wavelength is used
-
-        filter: `tuple`
-            first elements if one of the ChiantiPy.tools.filters object
-            second element is the width appropriate to the filter
-
-        label:  `str`
-            if set, creates a Spectrum[label] attribute
-
-        verbose: `bool`
-            if True, prints info to the terminal
-
-        '''
-        if not hasattr(self, 'IonInstances'):
-            print(' must set keepIons=1 in order to keep self.IonInstances')
-            return
-        #
-        if type(label)!= type(0):
-            if type(label) != str:
-                print(' label must either be zero or a string')
-                return
-        #
-        t1 = datetime.now()
-        #:
-        if hasattr(self, 'Wavelength'):
-                nWvl = len(self.Wavelength)
-                wavelength = self.Wavelength
-        elif type(wavelength) == int:
-            print(' a wavelength array must be given')
-            return
-        else:
-            self.Wavelength = wavelength
-            nWvl = len(wavelength)
-        lineSpectrum = np.zeros((self.NTempDens, nWvl), np.float64).squeeze()
-        for akey in sorted(self.IonInstances.keys()):
-            if verbose:
-                print( ' trying ion = %s'%(akey))
-#            thisIon = self.IonInstances[akey]
-            if not 'errorMessage' in sorted(self.IonInstances[akey].Intensity.keys()):
-                if verbose:
-                    print(' doing convolve on ion %s '%(akey))
-                self.IonInstances[akey].spectrum(wavelength, filter)
-#                lineSpectrum = np.add(lineSpectrum, self.IonInstances[akey].Spectrum['intensity'])
-                if 'errorMessage' in sorted(self.IonInstances[akey].Spectrum.keys()):
-                    print(self.IonInstances[akey].Spectrum['errorMessage'])
-                else:
-                    lineSpectrum += self.IonInstances[akey].Spectrum['intensity']
-#                if self.NTempDens == 1:
-#                    lineSpectrum += thisIon.Spectrum['intensity']
-#                else:
-#                    for iTempDen in range(self.NTempDens):
-#                        lineSpectrum[iTempDen] += thisIon.Spectrum['intensity'][iTempDen]
-            else:
-                if 'errorMessage' in sorted(self.IonInstances[akey].Intensity.keys()):
-                    print(self.IonInstances[akey].Intensity['errorMessage'])
-
-        self.LineSpectrum = {'wavelength':wavelength, 'intensity':lineSpectrum.squeeze()}
-        #
-        total = self.LineSpectrum['intensity']
-        #
-        # the following is required in order to be applied to both a 'spectrum' and a 'bunch' object
-        #
-        if hasattr(self, 'FreeFree'):
-            total += self.FreeFree['intensity']
-        if hasattr(self, 'FreeBound'):
-            total += self.FreeBound['intensity']
-        if hasattr(self, 'TwoPhoton'):
-            total += self.TwoPhoton['intensity']
-        self.Total = total
-        #
-        #
-        if self.NTempDens == 1:
-            integrated = total
-        else:
-            integrated = total.sum(axis=0)
-        #
-        t2 = datetime.now()
-        dt = t2 - t1
-        print(' elapsed seconds = %12.3e'%(dt.seconds))
-        #
-        if type(label) == type(''):
-            if hasattr(self, 'Spectrum'):
-                self.Spectrum[label] = {'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'em':self.Em,  'Abundance':self.AbundanceName}
-            else:
-                self.Spectrum = {label:{'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'em':self.Em,  'Abundance':self.AbundanceName}}
-        else:
-            self.Spectrum ={'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'Abundance':self.AbundanceName}
-        return
-        #
+#    def __init__(self, temperature, density):
+#        self.Temperature = temperature
+#        self.EDensity = density
+#        self.AbundanceName = chdata.Defaults['abundfile']
+#        self.AbundAll = chdata.Abundance[self.AbundanceName]['abundance']
+#        #
         # ---------------------------------------------------------------------------
         #
     def ionGate(self, elementList = None, ionList = None, minAbund=None, doLines=1, doContinuum=1, doWvlTest=1, doIoneqTest=1, includeDiel=False,  verbose=0):
@@ -148,7 +43,7 @@ class specTrails(object):
         minAbundAll = abundAll[nonzed].min()
         if minAbund:
             if minAbund < minAbundAll:
-                minAbund = minAbundAll
+                minAbund = float(minAbundAll)
         ionInfo = chio.masterListInfo()
         #
         if hasattr(self, 'Wavelength'):
@@ -400,50 +295,59 @@ class specTrails(object):
     #
     # -------------------------------------------------------------------------
     #
-    def saveData(self, filename):
+    def restoreData(self,  filename):
+        """
+
+        :param filename: filename where the pickle file of the saved data to be loaded
+        :type filename: str
+
+        """
+        with open(filename, 'rb') as inpt:
+            data = pickle.load(inpt)
+
+        for akey in data.keys():
+            setattr(self, akey,  data[akey])
+        return
+
+    #
+    # -------------------------------------------------------------------------
+    #
+    def saveData(self, filename, verbose=False):
         """
 
         :param filename: filename where the pickle file of the saved data will be stored
         :type filename: str
 
-        following running a ch.spectrum calculation, save the calculation as a dictionary to a pickle file
+        following running a multi-ion calculation (bunch, spectrum, mspectrum, ipymspectrum, radloss,
+        save the calculation as a dictionary to a pickle file
         """
-        data = {'temperature':self.Temperature, 'eDensity':self.EDensity,
-            'em':self.Em, 'abundanceName':self.AbundanceName, 'abundAll':self.AbundAll,
-            'ionsCalculated':self.IonsCalculated,
-            'defaults':self.Defaults, 'intensity':self.Intensity,
-            'nTemp':self.Ntemp, 'nDens':self.Ndens, 'nTempDens':self.NTempDens}
 
-#          'elementList':self.elementList, 'ionList':self.ionList,
-#            'minAbund':self.minAbund, 'keepIons':self.keepIons, 'em':self.em, 'abundance':self.abundance,
-#            'allLines':self.allLines}
+        t0 = datetime.now()
+        data = {'Filename':filename, 'Date':t0.strftime('%Y %B %d %H%M'),
+            'ClassName':self.__class__.__name__}
+        for aname in self.__dict__.keys():
+            if hasattr(self, aname):
+                data[aname] = getattr(self, aname)
 
-        if hasattr(self, 'Spectrum'):
-            data['spectrum'] = self.Spectrum
-        if hasattr(self, 'Wvl'):
-            data['wvl'] = self.Wvl
-        if hasattr(self, 'Wavelength'):
-            data['wavelength'] = self.Wavelength
-        if hasattr(self, 'WvlRange'):
-            data['wvlRange'] = self.WvlRange
-        if hasattr(self, 'PDensity'):
-            data['pDensity'] = self.PDensity
-        if hasattr(self, 'IonInstances'):
-            data['ionInstances'] = self.IonInstances
-        if hasattr(self, 'Xlabel'):
-            data['xlabel'] = self.Xlabel
-        if hasattr(self, 'Ylabel'):
-            data['ylabel'] = self.Ylabel
         with open(filename, 'wb') as outpt:
             pickle.dump(data, outpt)
 
-    def spectrumPlot(self, index=-1, integrated=False, saveFile=False, linLog = 'lin'):
+        if verbose:
+            for aname  in data:
+                print(' saving attribute:  %s'%(aname))
+
+
+
+    def spectrumPlot(self,  wvlRange=None, index=None, integrated=False, saveFile=False, linLog = 'lin',
+        doLabel=True, lw=1, doTitle=True, top=10):
         '''
         to plot the spectrum as a function of wavelength
 
         Keyword Arguments
         -----------------
 
+        wvlRange:  2 element tuple, list or array determines the wavelength range to plot
+
         index:  `int`
             selects the temperature of the calculated spectrum
 
@@ -456,50 +360,168 @@ class specTrails(object):
         linLog:  `str`
             should be either 'lin' for linear, or 'log' for logarithmic base10
 
+        doLabel: `bool`
+            if set to True, labels of the top spectral lines are added
+
+        lw:  `int`, width of the label line in matplotlib units (default=1)
+
+        doTitle:  `bool` if True, then a title is applied to the plot (default=True)
+
+
+        top:  integer
+            specifies to plot only the top strongest lines, default = 10
+
         '''
         fs = 14
+        #  fontsize for labels:
+        lfs = 12
         plt.figure()
-        mask = self.Em > 1.
-        if mask.sum() == 0:
-            self.Ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
+#        mask = self.Em > 1.
+#
+#        if mask.sum() == 0:
+#            self.Ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
+#        else:
+#            self.Ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$'
+        #
+#        self.Xlabel = 'Wavelength ('+self.Defaults['wavelength'].capitalize() +')'
+        #
+        if hasattr(self, 'Spectroscopic'):
+            title1 = self.Spectroscopic
+        elif hasattr(self, 'ClassName'):
+            title1 = self.ClassName
         else:
-            self.Ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$'
-        #
-        self.Xlabel = 'Wavelength ('+self.Defaults['wavelength'] +')'
-        #
-#        ymin = 10.**(np.log10(emiss.min()).round(0))
+            title1 = self.__class__.__name__
+
+        if wvlRange is None:
+            if hasattr(self, 'WvlRange'):
+                wvlRange = self.WvlRange
+            else:
+                wvlRange = [self.Intensity['wvl'].min(),  self.Intensity['wvl'].max()]
+                print(' wvlRange should be specified')
+
+
+        nTempDens = self.NTempDens
+
+
+
+
+        if integrated:
+            lineIntensity = self.Intensity['integrated']
+            lineWvl = self.Intensity['wvl']
+            lineIonS = self.Intensity['ionS']
+            wvlIndex = util.between(lineWvl, wvlRange)
+            if hasattr(self, 'Continuum'):
+                continuum = self.Continuum['intensity'].sum(axis=0)
+            else:
+                continuum = np.zeros_like(lineIntensity)
+
+            lineIntensity = lineIntensity[wvlIndex]
+            lineWvl = lineWvl[wvlIndex]
+            lineIonS = lineIonS[wvlIndex]
+        elif nTempDens == 1:
+            index = 0
+            lineIntensity = self.Intensity['intensity'][0]
+            if hasattr(self, 'Continuum'):
+                continuum = self.Continuum['intensity'][0]
+            else:
+                continuum = np.zeros_like(lineIntensity)
+            lineWvl = self.Intensity['wvl']
+            lineIonS = self.Intensity['ionS']
+        else:
+            if index is None:
+                index = nTempDens//2
+            lineIntensity = self.Intensity['intensity'][index]
+            lineWvl = self.Intensity['wvl']
+            lineIonS = self.Intensity['ionS']
+            if hasattr(self, 'Continuum'):
+                continuum = self.Continuum['intensity'][index]
+            else:
+                continuum = np.zeros_like(lineIntensity)
+        wvlIndex = util.between(lineWvl, wvlRange)
+
+        lineIntensity = lineIntensity[wvlIndex]
+        lineWvl = lineWvl[wvlIndex]
+        lineIonS = lineIonS[wvlIndex]
+        lineIonSpectr = []
+        for anion in lineIonS:
+            nameDict = util.convertName(anion)
+            lineIonSpectr.append(nameDict['spectroscopic'])
+        lineIonSpectr = np.asarray(lineIonSpectr)
+
+        self.Error = 0
+        if lineWvl.size == 0:
+            print('No lines in this wavelength interval')
+            self.Error = 1
+            self.Message = 'No lines in this wavelength interval'
+            return
+        elif top == 0:
+            top = lineWvl.size
+        elif lineWvl.size > top:
+            intsrt = np.argsort(lineIntensity)
+            lineWvl = lineWvl[intsrt[-top:]]
+            lineIonS = lineIonS[intsrt[-top:]]
+            lineIonSpectr = lineIonSpectr[intsrt[-top:]]
+            lineIntensity = lineIntensity[intsrt[-top:]]
+        else:
+            top = lineWvl.size
+
+
         #
         plt.ion()
         #
         if integrated:
+            spectrum = self.Spectrum['integrated']
             if 'wavelength' in sorted(self.Spectrum.keys()):
-                plt.plot(self.Spectrum['wavelength'], self.Spectrum['integrated'])
+                plt.plot(self.Spectrum['wavelength'], spectrum)
             elif 'wvl' in sorted(self.Spectrum.keys()):
                 plt.plot(self.Spectrum['wvl'], self.Spectrum['integrated'])
-            plt.xlabel(self.Xlabel,  fontsize=fs)
-            plt.ylabel(self.Ylabel,  fontsize=fs)
-            plt.title('integrated spectrum',  fontsize=fs)
+            title = title1 + ' integrated spectrum'
         else:
             nTempDens = self.NTempDens
             if nTempDens == 1:
             #
+                spectrum = self.Spectrum['intensity']
                 if 'wavelength' in sorted(self.Spectrum.keys()):
-                    plt.plot(self.Spectrum['wavelength'], self.Spectrum['intensity'])
+                    plt.plot(self.Spectrum['wavelength'], spectrum)
                 elif 'wvl' in sorted(self.Spectrum.keys()):
-                    plt.plot(self.Spectrum['wvl'], self.Spectrum['intensity'])
-                    plt.title(' Temperature = %10.2e K'%(self.Temperature),  fontsize=fs)
+                    plt.plot(self.Spectrum['wvl'], spectrum)
+                title = title1 + ' Temperature = %10.2e K'%(self.Temperature)
             else:
-                if index < 0:
+                if index is None:
                     index = nTempDens/2
+                spectrum = self.Spectrum['intensity'][index]
                 if 'wavelength' in sorted(self.Spectrum.keys()):
-                    plt.plot(self.Spectrum['wavelength'], self.Spectrum['intensity'][index])
+                    plt.plot(self.Spectrum['wavelength'], spectrum)
                 elif 'wvl' in sorted(self.Spectrum.keys()):
-                    plt.plot(self.Spectrum['wvl'], self.Spectrum['intensity'][index])
-                    plt.title(' Temperature = %10.2e K for index = %3i'%(self.Temperature[index], index),  fontsize=fs)
-                plt.xlabel(self.Xlabel,  fontsize=fs)
-                plt.ylabel(self.Ylabel,  fontsize=fs)
-        ylim = plt.ylim()
-        plt.ylim([0., ylim[1]])
+                    plt.plot(self.Spectrum['wvl'], spectrum)
+                title = title1 + ' Temperature = %10.2e K for index = %3i'%(self.Temperature[index],  index)
+        plt.xlabel(self.Spectrum['xlabel'],  fontsize=fs)
+        plt.ylabel(self.Spectrum['ylabel'],  fontsize=fs)
+        if doTitle:
+            plt.title(title, fontsize=fs)
+
+        if doLabel:
+            useFilter = self.Spectrum['filter']
+            useFactor = self.Spectrum['filterWidth']
+            for iwvl, awvl in enumerate(lineWvl):
+                filterFactor = useFilter(self.Spectrum['wavelength'], awvl, factor=useFactor).max()
+                # need to take into account the continuum
+                idx = np.argmin(np.abs(lineWvl[iwvl] - self.Wavelength))
+                spIntens = filterFactor*lineIntensity[iwvl] + continuum[idx]
+                plt.plot([awvl,  awvl], [0.,  1.2*spIntens], 'k',  lw=lw)
+                ypos = 1.25*spIntens
+                lbl = lineIonSpectr[iwvl] + ' %8.3f'%(awvl)
+                plt.text(awvl,  ypos, lbl, va='bottom', ha='center',rotation='vertical',  fontsize=lfs)
+
+        wdx = util.between(self.Spectrum['wavelength'],  wvlRange)
+        ymax = spectrum[wdx].max()
+#        plt.xlim(wvlRange)
+#        plt.ylim([0., ylim[1]])
+        if doLabel:
+            plt.axis([wvlRange[0],  wvlRange[1],  0., 1.8*ymax])
+        else:
+            plt.axis([wvlRange[0],  wvlRange[1],  0., 1.1*ymax])
+
         plt.tight_layout()
         if saveFile:
             plt.savefig(saveFile)
