@@ -16,7 +16,6 @@ import ChiantiPy.tools.data as chdata
 import ChiantiPy.tools.util as util
 import ChiantiPy.tools.io as io
 import ChiantiPy.tools.constants as const
-import ChiantiPy.Gui as chGui
 
 
 class continuum(ionTrails):
@@ -92,7 +91,6 @@ class continuum(ionTrails):
         self.ionization_potential = chdata.Ip[self.Z-1, self.Stage-1]*const.ev2Erg
         self.IprErg = self.Ipr*const.ev2Erg
         self.IprCm = 1.e+8/(const.ev2Ang/self.Ipr)
-
         # Set abundance
         if abundance is not None:
             if isinstance(abundance,  float):
@@ -106,12 +104,8 @@ class continuum(ionTrails):
                 self.AbundAll = ab['abundance']
 
         else:
-#            self.AbundanceName = self.Defaults['abundfile']
-        #
-#            ab = chdata.Abundance[self.AbundanceName]['abundance']
             self.Abundance = chdata.AbundanceDefault['abundance'][self.Z-1]
             self.AbundAll = chdata.AbundanceDefault['abundance']
-
         self.ioneqOne()
 
     def free_free_loss(self,  includeAbund=True, includeIoneq=True, **kwargs):
@@ -148,7 +142,7 @@ class continuum(ionTrails):
         if includeIoneq:
             prefactor *= self.ioneq_one(self.Stage, **kwargs)
 
-        self.free_free_loss = prefactor*(self.Z**2)*np.sqrt(self.Temperature)*gaunt_factor
+        self.FreeFreeLoss = prefactor*(self.Z**2)*np.sqrt(self.Temperature)*gaunt_factor
 
     def freeFree(self, wavelength, includeAbund=True, includeIoneq=True, **kwargs):
         """
@@ -183,6 +177,16 @@ class continuum(ionTrails):
             If True, include the ionization equilibrium in the final output
 
         """
+        if self.Em.max() == 1.:
+            ylabel = 'erg cm$^{-2}$ s$^{-1}$ sr$^{-1}$ \u212B$^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
+        else:
+            ylabel = 'erg cm$^{-2}$ s$^{-1}$ sr$^{-1}$ \u212B$^{-1}$'
+
+        if self.Defaults['wavelength'] == 'angstrom':
+            xlabel = 'Wavelength \u212B'
+        else:
+            xlabel = r'Wavelength ('+self.Defaults['wavelength'] +')'
+
         wavelength = np.atleast_1d(wavelength)
         # define the numerical prefactor
         prefactor = ((const.light*1e8)/3./const.emass
@@ -209,7 +213,8 @@ class continuum(ionTrails):
             energy_factor = const.planck*(1.e8*const.light)/wavelength
 
         free_free_emission = (prefactor[:,np.newaxis]*exp_factor*gf/energy_factor).squeeze()
-        self.FreeFree = {'intensity':free_free_emission, 'temperature':self.Temperature, 'wvl':wavelength, 'em':self.Em, 'ions':self.IonStr}
+        self.FreeFree = {'intensity':free_free_emission, 'temperature':self.Temperature, 'wvl':wavelength,
+            'em':self.Em, 'ions':self.IonStr, 'xlabel':xlabel,  'ylabel':ylabel}
 
     def freeFreeLoss(self, includeAbund=True, includeIoneq=True,  **kwargs):
         """
@@ -717,6 +722,16 @@ class continuum(ionTrails):
         wvl = np.asarray(wvl, np.float64)
         em = self.Em
 
+        if self.Em.max() == 1.:
+            ylabel = 'erg cm$^{-2}$ s$^{-1}$ sr$^{-1}$ \u212B$^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
+        else:
+            ylabel = 'erg cm$^{-2}$ s$^{-1}$ sr$^{-1}$ \u212B$^{-1}$'
+
+        if self.Defaults['wavelength'] == 'angstrom':
+            xlabel = 'Wavelength (\u212B)'
+        else:
+            xlabel = r'Wavelength ('+self.Defaults['wavelength'] +')'
+
         if includeAbund:
             abund = self.Abundance
         else:
@@ -735,7 +750,7 @@ class continuum(ionTrails):
                 return
         elif self.Z == self.Stage-1:
             #dealing with the fully ionized stage
-            self.Fblvl = {'mult':[2., 2.]}
+            self.Fblvl = {'mult':[1., 1.]}
             fblvl = self.Fblvl
         else:
             fblvlname = self.nameDict['filename']+'.fblvl'
@@ -823,6 +838,8 @@ class continuum(ionTrails):
 #                expf[0,itemp] = np.exp((iprLvlErg - 1.e+8*const.planck*const.light/wvl)/(const.boltzmann*atemp))
 #                fbrate[0,itemp] = ioneq[itemp]*em[itemp]*(const.planck*const.light/(1.e-8*wvl))**5 \
 #                    *const.verner*ratg[0]*expf[0,itemp]*vCross/atemp**1.5
+        # restrict calculations to temperatures where the ionization equ. is non-zero
+        goodT = [ it for it, anioneq in enumerate(self.IoneqOne) if anioneq > 0.]
         for ilvl in range(lvl1,nlvls):
             pqnIdx = pqn[ilvl] - 1
             lIdx = l[ilvl]
@@ -850,35 +867,32 @@ class continuum(ionTrails):
                     print(' ilvl %i   mygf.max() %10.2e'%(ilvl, np.max(mygf[ilvl])))
                 ratg[ilvl] = float(multr[ilvl])/float(mult[0]) # ratio of statistical weights
 
-                for itemp,  atemp in enumerate(temperature):
-                    phE = hnu
-                    expfun = np.exp((iprLvlErg - phE)/(const.boltzmann*atemp))
-                    expfunIsnan = np.isnan(expfun)
-                    expfunIsinf = np.isinf(expfun)
-                    if expfunIsnan.sum() > 0:
-                        print('%i some of expfun are nan %i'%(itemp, expfunIsnan.sum()))
-                        expfun[expfunIsnan] = 0.
-                    elif expfunIsinf.sum() > 0:
-                        print('%i some of expfun are inf %i'%(itemp, expfunIsinf.sum()))
-                        expfun[expfunIsinf] = 0.
-                    fbn[ilvl, itemp] = K0*phE**2*expfun*iprLvlErg**2*ratg[ilvl]*mygf[ilvl]/(atemp**(1.5)*float(pqn[ilvl]))
-                    fbnIsNan = np.isnan(fbn[ilvl, itemp])
-                    fbnIsInf = np.isinf(fbn[ilvl, itemp])
+                for itemp in goodT:
+                    atemp = self.Temperature[itemp]
+                    if ioneq[itemp] > 0.:
+                        phE = hnu
+                        expfun = np.exp((iprLvlErg - phE)/(const.boltzmann*atemp))
+                        expfunIsnan = np.isnan(expfun)
+                        expfunIsinf = np.isinf(expfun)
+                        if expfunIsnan.sum() > 0:
+                            print('%i some of expfun are nan %i'%(itemp, expfunIsnan.sum()))
+                            expfun[expfunIsnan] = 0.
+                        elif expfunIsinf.sum() > 0:
+                            print('%i some of expfun are inf %i'%(itemp, expfunIsinf.sum()))
+                            expfun[expfunIsinf] = 0.
+                        fbn[ilvl, itemp] = K0*phE**2*expfun*iprLvlErg**2*ratg[ilvl]*mygf[ilvl]/(atemp**(1.5)*float(pqn[ilvl]))
+                        fbnIsNan = np.isnan(fbn[ilvl, itemp])
+                        fbnIsInf = np.isinf(fbn[ilvl, itemp])
+
+                        if fbnIsNan.sum() > 0:
+                            print('%s  %i some fbn are Nan %i'%(self.IonStr, itemp, fbnIsNan.sum()))
+                            fbn[ilvl, itemp,  fbnIsNan] = 0.
+                        elif fbnIsInf.sum() > 0:
+                            print('%s %i some fbn are Inf %i'%(self.IonStr, itemp, fbnIsInf.sum()))
+                            fbn[ilvl, itemp,  fbnIsInf] = 0.
+                        mask[ilvl,itemp] = 1.e+8/wvl < (self.IprCm - ecm[ilvl])
+                        fbIntensity[ilvl, itemp] = abund*em[itemp]*ioneq[itemp]*fbn[ilvl, itemp]
 
-                    if fbnIsNan.sum() > 0:
-                        print('%i some fbn are Nan %i'%(itemp,  fbnIsNan.sum()))
-                        fbn[ilvl, itemp,  fbnIsNan] = 0.
-                    elif fbnIsInf.sum() > 0:
-                        print('%i some fbn are Inf %i'%(itemp,  fbnIsInf.sum()))
-                        fbn[ilvl, itemp,  fbnIsInf] = 0.
-                    mask[ilvl,itemp] = 1.e+8/wvl < (self.IprCm - ecm[ilvl])
-#                    if verbose:
-#                        print('iprcm %10.2e ecm %10.2e diff %10.2e'%(self.IprCm, ecm[ilvl], self.IprCm -ecm[ilvl]  ))
-#                        print('ilvl %i sum of mask %i'%(ilvl,  np.sum(mask[ilvl])))
-#                        print(' pqn %i np.sum(fbn[ilvl]) %10.2e'%(pqn[ilvl],   np.sum(fbn[ilvl,  itemp])))
-                    fbIntensity[ilvl, itemp] = abund*em[itemp]*ioneq[itemp]*fbn[ilvl, itemp]
-            else:
-                pass
         fbTest = fbIntensity.sum(axis=0)
         fbTestisNan = np.isnan(fbTest)
         fbTestisInf = np.isinf(fbTest)
@@ -893,7 +907,8 @@ class continuum(ionTrails):
         fb.fill_value = 0.
         #
         self.FreeBound = {'intensity':fb.squeeze(), 'temperature':temperature,'wvl':wvl, 'em':em, \
-            'abund':abund, 'ioneq':ioneq, 'gf':mygf, 'edgeLvlAng':edgeLvlAng,  'fbn':fbn}
+            'abund':abund, 'ioneq':ioneq, 'gf':mygf, 'edgeLvlAng':edgeLvlAng,  'fbn':fbn,
+            'xlabel':xlabel, 'ylabel':ylabel}
 
     def vernerCross(self, wvl):
         """
