@@ -93,13 +93,14 @@ class ipymspectrum(ionTrails, specTrails):
             #
         #
         if self.Em.max() == 1.:
-            ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
+            self.Ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
         else:
-            ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ $'
+            self.Ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$'
         #
-        #
-        #
-        xlabel = 'Wavelength ('+self.Defaults['wavelength'] +')'
+        if self.Defaults['wavelength'] == 'angstrom':
+            self.Xlabel = 'Wavelength (\u212B)'
+        else:
+            self.Xlabel = 'Wavelength ('+self.Defaults['wavelength'] +')'
         #
         self.AllLines = allLines
         #
@@ -121,6 +122,7 @@ class ipymspectrum(ionTrails, specTrails):
         wavelength = np.asarray(wavelength)
         nWvl = wavelength.size
         self.Wavelength = wavelength
+        self.WvlRange = [wavelength[0],  wavelength[-1]]
         ntemp = self.Ntemp
         #
         #
@@ -230,6 +232,8 @@ class ipymspectrum(ionTrails, specTrails):
         self.FreeBound = {'wavelength':wavelength, 'intensity':freeBound.squeeze()}
         self.LineSpectrum = {'wavelength':wavelength, 'intensity':lineSpectrum.squeeze()}
         self.TwoPhoton = {'wavelength':wavelength, 'intensity':twoPhoton.squeeze()}
+        cont = freeFree.squeeze() + freeBound.squeeze() + twoPhoton.squeeze()
+        self.Continuum = {'wavelength':wavelength, 'intensity':cont}
         #
         total = freeFree + freeBound + lineSpectrum + twoPhoton
         #
@@ -246,14 +250,17 @@ class ipymspectrum(ionTrails, specTrails):
         if type(label) == type(''):
             if hasattr(self, 'Spectrum'):
                 print(' hasattr = true')
-                self.Spectrum[label] = {'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'em':em,  'Abundance':self.AbundanceName,
-                                            'xlabel':xlabel, 'ylabel':ylabel}
+                self.Spectrum[label] = {'wavelength':wavelength, 'intensity':total.squeeze(),
+                    'filter':filter[0],   'filterWidth':filter[1], 'integrated':integrated, 'em':em,
+                    'Abundance':self.AbundanceName, 'xlabel':self.Xlabel, 'ylabel':self.Ylabel}
             else:
-                self.Spectrum = {label:{'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'em':em, 'Abundance':self.AbundanceName,
-                                'xlabel':xlabel, 'ylabel':ylabel}}
+                self.Spectrum = {label:{'wavelength':wavelength, 'intensity':total.squeeze(),
+                    'filter':filter[0],   'filterWidth':filter[1], 'integrated':integrated, 'em':em,
+                    'Abundance':self.AbundanceName,'xlabel':self.Xlabel, 'ylabel':self.Ylabel}}
         else:
-            self.Spectrum = {'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'em':em, 'Abundance':self.AbundanceName,
-                                'xlabel':xlabel, 'ylabel':ylabel}
+            self.Spectrum = {'wavelength':wavelength, 'intensity':total.squeeze(),
+                'filter':filter[0],   'filterWidth':filter[1], 'integrated':integrated, 'em':em,
+                'Abundance':self.AbundanceName, 'xlabel':self.Xlabel, 'ylabel':self.Ylabel}
     #
     # -------------------------------------------------------------------------
     #
