@@ -75,16 +75,17 @@ class mspectrum(ionTrails, specTrails):
 
         nTempDens = self.NTempDens
 
+        # unicode character for angstrom is \u212B
         if self.Em.max() == 1.:
-            ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
+            self.Ylabel = 'erg cm$^{-2}$ s$^{-1}$ sr$^{-1}$ \u212B$^{-1}$ ($\int\,$ N$_e\,$N$_H\,$d${\it l}$)$^{-1}$'
         else:
-            ylabel = r'erg cm$^{-2}$ s$^{-1}$ sr$^{-1} \AA^{-1}$ $'
+            self.Ylabel = 'erg cm$^{-2}$ s$^{-1}$ sr$^{-1}$ \u212B$^{-1}$'
         #
         #
         if self.Defaults['wavelength'] == 'angstrom':
-            xlabel = 'Wavelength ('+self.Defaults['wavelength'].capitalize() +')'
+            self.Xlabel = 'Wavelength (\u212B)'
         else:
-            xlabel = 'Wavelength ('+self.Defaults['wavelength'] +')'
+            self.Xlabel = 'Wavelength ('+self.Defaults['wavelength'] +')'
         #
         #
         self.AllLines = allLines
@@ -104,6 +105,7 @@ class mspectrum(ionTrails, specTrails):
         wavelength = np.asarray(wavelength)
         nWvl = wavelength.size
         self.Wavelength = wavelength
+        self.WvlRange = [wavelength[0],  wavelength[-1]]
         #
         proc = min([proc, mp.cpu_count()])
         #
@@ -245,6 +247,8 @@ class mspectrum(ionTrails, specTrails):
         self.FreeBound = {'wavelength':wavelength, 'intensity':freeBound.squeeze()}
         self.LineSpectrum = {'wavelength':wavelength, 'intensity':lineSpectrum.squeeze()}
         self.TwoPhoton = {'wavelength':wavelength, 'intensity':twoPhoton.squeeze()}
+        cont = freeFree.squeeze() + freeBound.squeeze() + twoPhoton.squeeze()
+        self.Continuum = {'wavelength':wavelength, 'intensity':cont}
         #
         total = freeFree + freeBound + lineSpectrum + twoPhoton
         #
@@ -259,13 +263,17 @@ class mspectrum(ionTrails, specTrails):
         #
         if type(label) == type(''):
             if hasattr(self, 'Spectrum'):
-                self.Spectrum[label] = {'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'ions':self.IonsCalculated, 'em':em,
-                'Abundance':self.AbundanceName, 'xlabel':xlabel, 'ylabel':ylabel, 'minAbund':minAbund}
+                self.Spectrum[label] = {'wavelength':wavelength, 'intensity':total.squeeze(),
+                'filter':filter[0],   'filterWidth':filter[1], 'integrated':integrated,
+                'ions':self.IonsCalculated, 'em':em, 'Abundance':self.AbundanceName, 'xlabel':self.Xlabel,
+                'ylabel':self.Ylabel, 'minAbund':minAbund}
             else:
-                self.Spectrum = {label:{'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,   'width':filter[1], 'integrated':integrated, 'ions':self.IonsCalculated, 'em':em,
-                'Abundance':self.AbundanceName, 'xlabel':xlabel, 'ylabel':ylabel}, 'minAbund':minAbund}
+                self.Spectrum = {label:{'wavelength':wavelength, 'intensity':total.squeeze(),
+                'filter':filter[0],   'filterWidth':filter[1], 'integrated':integrated,
+                'ions':self.IonsCalculated, 'em':em, 'Abundance':self.AbundanceName, 'xlabel':self.Xlabel,
+                'ylabel':self.Ylabel}, 'minAbund':minAbund}
         else:
-            self.Spectrum ={'wavelength':wavelength, 'intensity':total.squeeze(), 'filter':filter[0].__name__,
-            'width':filter[1], 'integrated':integrated, 'ions':self.IonsCalculated, 'em':em,
-            'Abundance':self.AbundanceName, 'xlabel':xlabel, 'ylabel':ylabel, 'minAbund':minAbund,
-            'todo':self.Todo}
+            self.Spectrum ={'wavelength':wavelength, 'intensity':total.squeeze(),
+            'filter':filter[0], 'filterWidth':filter[1], 'integrated':integrated,
+            'ions':self.IonsCalculated, 'em':em, 'Abundance':self.AbundanceName, 'xlabel':self.Xlabel,
+            'ylabel':self.Ylabel, 'minAbund':minAbund, 'todo':self.Todo}
